/**
 * @author Mario García Arranz <mariogarranz@gmail.com>
 */

/**
 * Integration of Spil Games API
 * @param {Number} id - Game identifier provieded by Spil Games
 */
DistLib.PartnerAPI.SpilGames = function( cfg, game){

	DistLib.PartnerAPI.call(this, cfg);

	this.game = game;
	this._id = '576742227280295765';

	this.useBrandingLogo = true;

	this.hasOwnSplashScreen = true;
	this.isLogoClickable = false;
	this.defaulAdsEnabled = false;

	this._splashData = null;
	this._moreGamesLink = null;

	this.brandingLogoData = null;
	this.brandingLgoURL = null;
	this.brandingLogoAction = null;

	// Constant values, may be changed in case Spil updates any of them
	this._scriptURL = 'js/game.js';

	this._spilDivId = 'spilgames-splash-screen';
	this._spilDivClass = 'spilgames-splash-screen-gone';
	this._spilCssStyle = '#spilgames-splash-screen{\nwidth: 100%;\nheight: 100%;\nbackground: url("http://www8.agame.com/mirror/img/Splash_Image_A10.png")\ntop center no-repeat;\nposition: absolute;\nz-index: 10000;\nbackground-size: 90%;\nbackground-color:#3890ae;\n}\n.spilgames-splash-screen-gone{\ndisplay:none !important;\n}';

	this._splashScreenTime = 3000;


	this.loaded = false;
	this._startedLoadingAPI = false;

	this.initialize();

};

DistLib.PartnerAPI.SpilGames.prototype = Object.create(DistLib.PartnerAPI.prototype);
DistLib.PartnerAPI.SpilGames.prototype.constructor = DistLib.PartnerAPI.SpilGames;



// Interface methods definition
// ------------------------------------------------------------------------------

/**
 * Adds the required HTML elements, then loads Spil Games API.
 */
DistLib.PartnerAPI.SpilGames.prototype.initialize = function(){

	this._addCssStyle();
	this._addDivLayer();
	this._loadScript(this._loadAPI,this);
	this._setupAPIControl();

};

/**
 * Loads the partner's API script, then executes the callback function
 * @param  {Function} callback        - Function to be executed when the script is fully loaded
 * @param  {Object}   callbackContext - Context of the function
 */
DistLib.PartnerAPI.SpilGames.prototype._loadScript = function(callback,callbackContext){

	var htmlScriptTag = document.createElement('script');
	var head = document.getElementsByTagName('head')[0];

	htmlScriptTag.type = 'text/javascript';
	htmlScriptTag.src = this._scriptURL;

	/*htmlScriptTag.onreadystatechange = function(){ 
		console.log("onreadystatechange");
		callback.apply(callbackContext); 
	};*/
	htmlScriptTag.onload = function(){ 
		if(!this._startedLoadingAPI){
			callback.apply(callbackContext); 
		}
	};

	this._startedLoadingAPI = true;

	head.appendChild(htmlScriptTag);

};

/**
 * Displays the partners API Splash screen. After the splash screen is finished, executes the callback function
 * 
 * @param  {Function} callback        - Function to be executed when the splash screen is finished
 * @param  {Object}   callbackContext - Context of the function
 */
DistLib.PartnerAPI.SpilGames.prototype.showSplashScreen = function(callback,callbackContext){

		if(typeof callback !== 'undefined'){
			GameAPI.Branding.displaySplashScreen(function(){
				callback.apply(callbackContext);
			});
		} else {
			GameAPI.Branding.displaySplashScreen(function(){});
		}



};

/**
 * Executes the 
 * @return {[type]} [description]
 */
DistLib.PartnerAPI.SpilGames.prototype.goToMoreGames = function(){

	this._moreGamesLink.action.call();

	return '[spil generated url]';

};

DistLib.PartnerAPI.SpilGames.prototype.showAd = function(callback, callbackContext){

	if(typeof callback !== 'undefined'){
		callback.apply(callbackContext);
	}

	GameAPI.GameBreak.request(pauseGame, resumeGame);

};



// Own methods definition
// ------------------------------------------------------------------------------


/**
 * Loads Spil Games API
 */
DistLib.PartnerAPI.SpilGames.prototype._loadAPI = function(){

	var _this = this;

	var spilData = {
		id: this._id
	};

	GameAPI.loadAPI( function (apiInstance) {

		_this._splashData = apiInstance.Branding.getSplashScreen();
		_this._moreGamesLink = apiInstance.Branding.getLink('more_games');
		_this.brandingLogoData = apiInstance.Branding.getLogo();
		_this.brandingLogoURL = _this.brandingLogoData.image;
		_this.brandingLogoAction = _this.brandingLogoData.action;

		if(_this.brandingLogoURL === false){
			_this.useBrandingLogo = false;
		}

		_this.loaded = true;


      //  console.log('GameAPI version ' + apiInstance.version + ' loaded!');

    }, spilData);

};

/**
 * Adds a div layer that will be used by Spil Games API
 */
DistLib.PartnerAPI.SpilGames.prototype._addDivLayer = function(){

	var htmlDivTag = document.createElement('div');

	htmlDivTag.id = this._spilDivId;
	htmlDivTag.className = this._spilDivClass;

	document.body.insertBefore(htmlDivTag,document.body.firstChild);


};

/**
 * Adss CSS styling for div layer
 */
DistLib.PartnerAPI.SpilGames.prototype._addCssStyle = function(){

	var htmlStyleTag = document.createElement('style');
	var head = document.getElementsByTagName('head')[0];

	htmlStyleTag.innerHTML = this._spilCssStyle;

	head.appendChild(htmlStyleTag);

};



DistLib.PartnerAPI.SpilGames.prototype.sendScore = function(score){

	GameAPI.Score.submit(score);

};


DistLib.PartnerAPI.SpilGames.prototype.achievementUnlocked = function(achievementName, achievementNumber){

	var award = { award: 'award' + achievementNumber };

	GameAPI.Award.submit(award);

};

/**
 * Adds global functions to allow Spil control certain aspects of the game
 */
DistLib.PartnerAPI.SpilGames.prototype._setupAPIControl = function(){

	var _this = this;

	window.pauseGame = function(){

		_this.game.pause(true);
		_this.game.setSound(false);

	};

	window.resumeGame = function(){

		_this.game.pause(false);
		_this.game.setSound(true);

	};

};

// Generic PartnerJS usage:

DistLib.PartnerAPI.PartnerJS = DistLib.PartnerAPI.SpilGames;